@@ -293,8 +293,8 @@ class TextToAudioResponse(BaseModel):
     }
 
 
-def init_provider(payload: TextGenerationPayload) -> object:
-    return provider_map.get(payload.provider, AsyncAUTO)(
+async def init_provider(payload: TextGenerationPayload) -> object:
+    return provider_map.get(payload.provider, AsyncGPT4FREE)(
         is_conversation=False,  # payload.is_conversation,
         max_tokens=payload.max_tokens,
         timeout=payload.timeout,
@@ -332,7 +332,7 @@ async def non_stream(payload: TextGenerationPayload) -> ProviderResponse:
 
     **NOTE** : Example values are modified for illustration purposes.
     """
-    provider_obj: AsyncGPT4FREE = init_provider(payload)
+    provider_obj: AsyncGPT4FREE = await init_provider(payload)
     ai_generated_text: str = await provider_obj.chat(payload.prompt)
     return ProviderResponse(
         provider=(
@@ -346,7 +346,7 @@ async def non_stream(payload: TextGenerationPayload) -> ProviderResponse:
 
 
 async def generate_streaming_response(payload: TextGenerationPayload) -> Generator:
-    provider_obj = init_provider(payload)
+    provider_obj = await init_provider(payload)
     async_chat = await provider_obj.chat(payload.prompt, stream=True)
     async for text in async_chat:
         response = ProviderResponse(
@@ -482,7 +482,7 @@ async def redirect_image_generation(prompt: str):
     )
 
 
-@app.post("/audio", name="text-to-audio")
+@app.post("/voice", name="text-to-voice")
 @api_exception_handler
 async def text_to_audio(
     payload: TextToAudioPayload, request: Request
@@ -508,7 +508,7 @@ async def text_to_audio(
     return TextToAudioResponse(url=f"{host}/static/audios/" + filename)
 
 
-@app.get("/audio", name="text-to-audio (bytes)")
+@app.get("/voice", name="text-to-voice (bytes)")
 @api_exception_handler
 async def text_to_audio_bytes(
     message: str,
